/* beautiful-react-hooks version: 0.25.3 */
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _rollupPluginBabelHelpers = require('./_virtual/_rollupPluginBabelHelpers.js');
var react = require('react');
var isClient = require('./utils/isClient.js');
var isAPISupported = require('./utils/isAPISupported.js');
var safelyParseJson = require('./utils/safelyParseJson.js');

var errorMessageSSR = 'localStorage is not supported, this could happen because you\'re using the useLocalStorage' + ' hook whilst server side rendering.';
var errorMessageIsNotSupported = 'localStorage is not supported, this could happen because window.localStorage is ' + 'not supported by your current browser';

var useLocalStorage = function useLocalStorage(localStorageKey, defaultValue) {
  if (!isClient.default) {
    console.warn(errorMessageSSR);
    return [JSON.stringify(defaultValue), function () {
      return undefined;
    }];
  }

  if (!isAPISupported.default('localStorage')) {
    console.warn(errorMessageIsNotSupported);
    return [JSON.stringify(defaultValue), function () {
      return undefined;
    }];
  }

  var _useState = react.useState(safelyParseJson.default(window.localStorage.getItem(localStorageKey) || JSON.stringify(defaultValue))),
      _useState2 = _rollupPluginBabelHelpers.slicedToArray(_useState, 2),
      value = _useState2[0],
      setValue = _useState2[1];

  react.useEffect(function () {
    window.localStorage.setItem(localStorageKey, JSON.stringify(value));
  }, [localStorageKey, value]);
  return [value, setValue];
};

exports.default = useLocalStorage;
